@@ -6,8 +6,8 @@ from typing import NamedTuple
 from mcipc.query.proto.common import MAGIC
 from mcipc.query.proto.common import decodeall
 from mcipc.query.proto.common import ip_or_hostname
+from mcipc.query.proto.common import random_session_id
 from mcipc.query.proto.common import BigEndianSignedInt32
-from mcipc.query.proto.common import ChallengeToken
 from mcipc.query.proto.common import IPAddressOrHostname
 from mcipc.query.proto.common import Type
 
@@ -18,10 +18,10 @@ __all__ = ['Request', 'BasicStats', 'BasicStatsMixin']
 class Request(NamedTuple):
     """Basic statistics request packet."""
 
-    magic: bytes
-    type: Type
-    session_id: BigEndianSignedInt32
-    challenge_token: ChallengeToken
+    magic: bytes = MAGIC
+    type: Type = Type.STAT
+    session_id: BigEndianSignedInt32 = BigEndianSignedInt32()
+    challenge_token: BigEndianSignedInt32 = BigEndianSignedInt32()
 
     def __bytes__(self):
         """Returns the packet as bytes."""
@@ -31,17 +31,6 @@ class Request(NamedTuple):
         payload += bytes(self.challenge_token)
         return payload
 
-    @classmethod
-    def create(cls, challenge_token: ChallengeToken,
-               session_id: BigEndianSignedInt32 = None) -> Request:
-        """Creates a new request with the specified challenge
-        token and the specified or a random session ID.
-        """
-        if session_id is None:
-            session_id = BigEndianSignedInt32.random_session_id()
-
-        return cls(MAGIC, Type.STAT, session_id, challenge_token)
-
 
 class BasicStats(NamedTuple):
     """Basic statistics response packet."""
@@ -92,5 +81,8 @@ class BasicStatsMixin:  # pylint: disable=R0903
     @property
     def basic_stats(self) -> BasicStats:
         """Returns basic stats"""
-        request = Request.create(self._challenge_token)
-        return self.communicate(request, BasicStats)
+        request = Request(
+            session_id=random_session_id(),
+            challenge_token=self.challenge_token)
+        bytes_ = self.communicate(bytes(request))
+        return BasicStats.from_bytes(bytes_)
