@@ -3,7 +3,7 @@
 from __future__ import annotations
 from enum import Enum
 from functools import partial
-from ipaddress import ip_address, IPv4Address, IPv6Address
+from ipaddress import IPv4Address, IPv6Address, ip_address
 from random import randint
 from typing import Iterable, Iterator, Union
 
@@ -12,8 +12,7 @@ __all__ = [
     'MAGIC',
     'decodeall',
     'ip_or_hostname',
-    'BigEndianSignedInt32',
-    'ChallengeToken',
+    'random_session_id',
     'IPAddressOrHostname',
     'Type'
 ]
@@ -21,6 +20,8 @@ __all__ = [
 
 MAGIC = b'\xfe\xfd'
 SESSION_ID_MASK = 0x0F0F0F0F
+
+
 IPAddressOrHostname = Union[IPv4Address, IPv6Address, str]
 
 
@@ -39,12 +40,28 @@ def ip_or_hostname(string: str) -> IPAddressOrHostname:
         return string
 
 
+def random_session_id() -> BigEndianSignedInt32:
+    """Returns a random session ID.
+    See: https://wiki.vg/Query#Generating_a_Session_ID
+    """
+
+    random = randint(BigEndianSignedInt32.MIN, BigEndianSignedInt32.MAX)
+    return BigEndianSignedInt32(random & SESSION_ID_MASK)
+
+
 class BigEndianSignedInt32(int):
     """A big-endian, signed int32."""
 
     MIN = -2_147_483_648
     MAX = 2_147_483_647
 
+    def __init__(self, *_):
+        """Checks the boundaries."""
+        super().__init__()
+
+        if not self.MIN <= self <= self.MAX:
+            raise ValueError('Signed int32 out of bounds:', self)
+
     def __bytes__(self):
         """Returns the int as bytes."""
         return self.to_bytes(4, 'big', signed=True)
@@ -54,24 +71,6 @@ class BigEndianSignedInt32(int):
         """Reutns the int from the given bytes."""
         return super().from_bytes(bytes_, 'big', signed=True)
 
-    @classmethod
-    def random_session_id(cls) -> BigEndianSignedInt32:
-        """Returns a random session ID.
-        See: https://wiki.vg/Query#Generating_a_Session_ID
-        """
-        return cls(randint(cls.MIN, cls.MAX) & SESSION_ID_MASK)
-
-
-class ChallengeToken(BigEndianSignedInt32):
-    """A Query challenge token."""
-
-    @classmethod
-    def from_handshake(cls, bytes_: bytes):
-        """Returns the challenge token from a handshake response.
-        See: https://wiki.vg/Query#Handshake
-        """
-        return cls(bytes_[:-1].decode())
-
 
 class Type(Enum):
     """Request type."""
